SystemOrganization addCategory: #MetaMinerva!
SystemOrganization addCategory: #'MetaMinerva-Experiments'!

Object subclass: #MinObjects
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva'!

!MinObjects commentStamp: 'JohanBriglia 9/5/2013 14:46' prior: 0!
Copr. Johan BRIGLIA 2013

johan.briglia@gmail.com

This file is part of MetaMinerva

MetaMinerva is a computer program whose purpose is to modelize the
human memory according to fractal appariement theories. MetaMinerva
is an improvement of Hintzman's Minerva2 ideas (1986) and do not use
any part of the original software.

MetaMinerva is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
http://www.cecill.info

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms.!

MinObjects subclass: #Echo
	instanceVariableNames: 'echoValues fluence gathering threshold numberOfModalities'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva'!

!Echo methodsFor: 'gears' stamp: 'JohanBriglia 9/5/2013 14:51'!
calculateFluenceFrom: someTraces

	"calculate the fluence as a mean of someTraces similarities pondered by their activations"

	fluence :=
		(1 to: (someTraces similarities size)) inject: 0 into: [ :sum :index |
			(someTraces similarities at: index) abs * (someTraces activations at: index) + sum
		]! !

!Echo methodsFor: 'gears' stamp: 'JohanBriglia 9/5/2013 14:52'!
calculateFrom: someTraces and: someActivations

	"Calculate the echo values from the average pondered contextual traces"

	echoValues :=
		(1 to: numberOfModalities) collect: [ :index |
			((1 to: (someTraces size)) inject: 0 into: [ :sum :traceNumber |
				((someTraces at: traceNumber) at: index) * (someActivations at: traceNumber) + sum
			]) roundTo: 0.01
		].
! !

!Echo methodsFor: 'gears' stamp: 'JohanBriglia 9/5/2013 14:52'!
calculateGathering

	"Gathering creation as gestalt interpretation from spatial and activity proximities"
	
	(numberOfModalities = 2) ifTrue: [gathering := {1. 2}]
	ifFalse: [
	
	Minerva fractal
		ifTrue: [ | j |	
			gathering := OrderedCollection new.
			gathering add: 1.
			j := 1.
			self threshold: fluence.
	
			(1 to: (numberOfModalities - 1)) do: [:each |
				((echoValues at: (each + 1)) 
					between: ((echoValues at: each) - threshold)
					and: ((echoValues at: each) + threshold))
				ifFalse: [j := j + 1].
				gathering add: j].
		]
		ifFalse: [ gathering := (1 to: numberOfModalities)]
	]! !

!Echo methodsFor: 'values' stamp: 'JohanBriglia 8/2/2012 14:18'!
echoValues

	"Values of the echo"

	^echoValues ifNil: [echoValues := OrderedCollection new]! !

!Echo methodsFor: 'values' stamp: 'JohanBriglia 8/2/2012 14:19'!
fluence

	"Fluence of the Echo.
	This is what Minerva Returns"

	^fluence ifNil: [fluence := 0]! !

!Echo methodsFor: 'settings' stamp: 'JohanBriglia 8/2/2012 16:27'!
gathering

	"Collection of the echo gathering.
	is used like pointers so it can be used by any probe
	ex : #(1 1 1 2 2) means #([x x x] [x x])"

	^gathering ifNil: [gathering := OrderedCollection new]! !

!Echo methodsFor: 'settings' stamp: 'JohanBriglia 1/17/2013 04:23'!
initialize

	"Initialization of the variables within the object Echo"

	super initialize.
	self echoValues ;
		fluence;
		gathering.! !

!Echo methodsFor: 'gears' stamp: 'JohanBriglia 9/5/2013 14:53'!
numberOfModalities: anInteger

	"echo numberOfModalities"

	numberOfModalities := anInteger! !

!Echo methodsFor: 'gears' stamp: 'JohanBriglia 11/22/2012 18:51'!
threshold

	"limen used to ponder the echo gathering"
	
	^threshold ifNil: [threshold := 0]! !

!Echo methodsFor: 'gears' stamp: 'JohanBriglia 9/5/2013 14:56'!
threshold: x

	"Formula used to calculate threshold from fluence
	  it is usually the absolute value of fluence
	  it can be changed, but the behavior of the model will be alterate and even can stop emergence"
	
	threshold := (x abs)! !

!MinObjects methodsFor: 'gears' stamp: 'JohanBriglia 11/25/2012 17:13'!
confrontationFormulaWith: x and: y

	"This is the primitive formula used to confront a probe modality with a trace modality"
	
	^(
		(x + y / 2) abs - (x - y / 2) abs
	)! !

MinObjects subclass: #Probe
	instanceVariableNames: 'probeValues numberOfModalities'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva'!

!Probe methodsFor: 'settings' stamp: 'JohanBriglia 8/2/2012 14:22'!
initialize

	"Initialization of the variables within the object Probe"

	super initialize.
	self numberOfModalities ;
		probeValues.! !

!Probe methodsFor: 'gears' stamp: 'JohanBriglia 8/2/2012 16:59'!
newProbeWith: aProbe

	"Return an error if aProbe doesn't fit in the model"

	(aProbe size = numberOfModalities) ifFalse: [Smalltalk error: 'wrong number of modalities'].
	probeValues := aProbe.
		
	 ^self! !

!Probe methodsFor: 'values' stamp: 'JohanBriglia 11/25/2012 15:40'!
numberOfModalities 

	"Number of modalities used by the current Minerva"

	^numberOfModalities ifNil: [numberOfModalities := 0]! !

!Probe methodsFor: 'settings' stamp: 'JohanBriglia 11/25/2012 15:43'!
numberOfModalities: anInteger

	"set numberOfModalities to anInteger"

	numberOfModalities := anInteger.
		
	 ^self! !

!Probe methodsFor: 'values' stamp: 'JohanBriglia 8/2/2012 16:06'!
probeValues

	"list of values in the probe"

	^probeValues ifNil: [probeValues := OrderedCollection new]! !

MinObjects subclass: #Traces
	instanceVariableNames: 'tracesValues activations similarities numberOfTraces'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva'!

Traces subclass: #Trace
	instanceVariableNames: 'modalities gathering similarity'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva'!

!Trace methodsFor: 'gears' stamp: 'JohanBriglia 12/4/2012 23:53'!
compareWith: aProbe

	"Compare each modality between the trace and the probe.
	Calculate and send the relative similarity value"

	|gatheredProbe|
	
	similarity := 0.
	gatheredProbe := self gatherProbe: aProbe.
	modalities doWithIndex: [:each :index |
		similarity := similarity +
			(self confront: each and: (gatheredProbe at: index))].
	similarity := similarity / (gatheredProbe size).
	^similarity! !

!Trace methodsFor: 'gears' stamp: 'JohanBriglia 1/17/2013 02:48'!
confront: aTraceModality and: aProbeValue

	"Calculate the similarity between a trace modality and a probe modality.
	It uses injectProbe: if the trace modality is an instance of Minerva"

	(aProbeValue size = 1)
		ifTrue: [
			^(self confrontationFormulaWith: (aProbeValue at: 1) and: aTraceModality)].
			^(aTraceModality injectProbe: aProbeValue)! !

!Trace methodsFor: 'settings' stamp: 'JohanBriglia 8/2/2012 16:23'!
gatherProbe: aProbe 

	"Gather aProbe like the trace gathering"

	|gatheredProbe|

	gatheredProbe := OrderedCollection new.
	1 to: (gathering last) do: [:each |
		gatheredProbe add: (OrderedCollection new)].
	gathering doWithIndex: [:each :index |
		(gatheredProbe at: each) add: (aProbe at: index)].
	^gatheredProbe! !

!Trace methodsFor: 'values' stamp: 'JohanBriglia 8/2/2012 16:26'!
gathering

	"Collection of the trace gathering.
	is used like pointers so it can be used by any probe
	ex : #(1 1 1 2 2) means #([x x x] [x x])"

	^gathering ifNil: [gathering := OrderedCollection new]! !

!Trace methodsFor: 'values' stamp: 'JohanBriglia 9/5/2013 15:17'!
gathering: aGathering

	"set this Trace gathering"

	gathering := aGathering! !

!Trace methodsFor: 'settings' stamp: 'JohanBriglia 8/2/2012 16:29'!
initialize

	"Initialization of the variables within the object Trace"

	super initialize.
	self gathering ;
		modalities ;
		similarity.! !

!Trace methodsFor: 'values' stamp: 'JohanBriglia 8/2/2012 16:29'!
modalities

	"List of modalities values of the trace"

	^modalities ifNil: [modalities := OrderedCollection new]! !

!Trace methodsFor: 'values' stamp: 'JohanBriglia 9/5/2013 14:59'!
modalities: someModalities

	"set modalities as someModalities"

	modalities := someModalities! !

!Trace methodsFor: 'settings' stamp: 'JohanBriglia 3/31/2013 14:15'!
newWith: someModalities gathered: someGathering

	"set modalities and gathering of a new trace.
	  Create new instances of Minerva as modality if needed"	
	
	gathering := someGathering.
	modalities := 
		(self gatherProbe: someModalities) collect: [ :each |
			each size = 1
			ifTrue: [each at: 1]
			ifFalse: [Minerva new startWith: each]
		].
		
	 ^self! !

!Trace methodsFor: 'values' stamp: 'JohanBriglia 8/2/2012 16:32'!
similarity

	"Similarity value between the trace and the probe"

	^similarity ifNil: [similarity := 0]! !

!Traces methodsFor: 'values' stamp: 'JohanBriglia 9/5/2013 14:56'!
activations

	"List of pondered similarity values of the current Minerva"

	^activations ifNil: [activations := Array new]! !

!Traces methodsFor: 'gears' stamp: 'JohanBriglia 1/17/2013 04:32'!
calculateSimilaritiesWith: aProbe

	"Compare each trace with the probe and calculate similiarities, then activations"
	
	| intensity |

	similarities :=
		tracesValues collect: [:each | each compareWith: aProbe].

	intensity := similarities inject: 0 into: [ :sum :each | each abs + sum].
	
	(intensity = 0) 
		ifTrue: [activations := similarities]
		ifFalse: [activations := similarities collect: [ :each | each / intensity]]! !

!Traces methodsFor: 'settings' stamp: 'JohanBriglia 11/23/2012 23:03'!
initialize

	"Initialization of the variables within the object Traces"

	super initialize.
	self similarities ;
		tracesValues.! !

!Traces methodsFor: 'gears' stamp: 'JohanBriglia 4/17/2013 14:04'!
newTraceFrom: aMinerva

	"create a new trace mixing probe and echo values with echo gathering"

	tracesValues add: (Trace new
		newWith: ((aMinerva probe probeValues) + (aMinerva echo echoValues) / 2) gathered: (aMinerva echo gathering))! !

!Traces methodsFor: 'values' stamp: 'JohanBriglia 8/2/2012 17:07'!
numberOfTraces

	"number of traces in the current Minerva"
	
	^numberOfTraces ifNil: [numberOfTraces := 0]! !

!Traces methodsFor: 'values' stamp: 'JohanBriglia 8/2/2012 16:15'!
similarities

	"List of similarity values of the current Minerva"

	^similarities ifNil: [similarities := OrderedCollection new]! !

!Traces methodsFor: 'values' stamp: 'JohanBriglia 8/2/2012 16:16'!
tracesValues

	"List of traces within the current Minerva"

	^tracesValues ifNil: [tracesValues := OrderedCollection new]! !

Object subclass: #Minerva
	instanceVariableNames: 'probe traces echo contextualTraces'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva'!

Minerva class
	instanceVariableNames: 'learn fractal'!

Minerva class
	instanceVariableNames: 'learn fractal'!

!Minerva class methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 1/17/2013 04:43'!
fractal

	^fractal ifNil: [fractal := true]! !

!Minerva class methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 1/17/2013 04:43'!
fractal: aBoolean

	fractal := aBoolean! !

!Minerva class methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 1/17/2013 03:08'!
learn

	"Boolean indicating Minerva is currently learning or testing"

	^learn ifNil: [learn := true]! !

!Minerva class methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 14:49'!
learn: aBoolean

	"define the learn capacity
	  true : integration
	  false : testing"

	learn := aBoolean! !

!Minerva methodsFor: 'objects' stamp: 'JohanBriglia 11/23/2012 22:39'!
contextualTraces

	"Send the contextual traces"

	^contextualTraces ifNil: [contextualTraces := Array new]! !

!Minerva methodsFor: 'gears' stamp: 'JohanBriglia 9/5/2013 15:00'!
echo

	"echo object of the current Minerva"

	^echo ifNil: [echo := Echo new]! !

!Minerva methodsFor: 'settings' stamp: 'JohanBriglia 1/17/2013 03:40'!
initialize

	"Initialization of the objects probe, traces, echo and contextualTraces within the object Minerva"

	super initialize.
	self echo ;
		probe ;
		traces ;
		contextualTraces.! !

!Minerva methodsFor: 'gears' stamp: 'JohanBriglia 1/17/2013 03:42'!
injectProbe: aProbe

	"Gears of the model, this method inject a probe into the traces in order to calculate the echo.
	 Then a new trace is written if the class variable 'learn' says so.
	 Finally send the echo fluence"

	probe newProbeWith: aProbe.
	traces calculateSimilaritiesWith: aProbe.
	self refreshContextualTraces.
	echo calculateFluenceFrom: traces.
	echo calculateFrom: contextualTraces and: (traces activations).
	echo calculateGathering.
	Minerva learn ifTrue: [traces newTraceFrom: self].
	^echo fluence! !

!Minerva methodsFor: 'gears' stamp: 'JohanBriglia 7/1/2013 17:12'!
integrateProbe: aProbe

	"inject a probe and return an Array with fluence, echo modalities and gathering"
	
	Minerva learn: true.
	
	^Array with: ({ self injectProbe: aProbe} )
			with: (self echo echoValues)
			with: (self echo gathering) ! !

!Minerva methodsFor: 'gears' stamp: 'JohanBriglia 12/3/2012 02:26'!
integrateProbes: aBunchOfProbes

	"integrate several probes and return an Array with fluence, echo modalities and gathering for each"
	
	| results |
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Integration loading' 
		at: Display center from: 0 to: aBunchOfProbes size
		during: [ :bar |
			aBunchOfProbes doWithIndex: [:each :index |
				bar value: index.
  				results add: (self integrateProbe: each)]].
	^results! !

!Minerva methodsFor: 'settings' stamp: 'JohanBriglia 9/5/2013 15:02'!
numberOfModalities: anInteger

	"set probe and echo numberOfModalities of the current Minerva as anInteger"

	probe numberOfModalities: anInteger.
	echo numberOfModalities: anInteger.! !

!Minerva methodsFor: 'objects' stamp: 'JohanBriglia 8/2/2012 13:40'!
probe

	"The variable probe of the current Minerva containing an object Probe"

	^probe ifNil: [probe := Probe new]! !

!Minerva methodsFor: 'settings' stamp: 'JohanBriglia 1/17/2013 04:12'!
refreshContextualTraces

	"refresh the contextual traces"

	contextualTraces :=
		(traces tracesValues) collect: [ :eachTrace | | traceModalities |
			traceModalities := OrderedCollection new.
			(eachTrace modalities) do: [ :eachModality | 
				eachModality isNumber
					ifTrue: [traceModalities add: eachModality]
					ifFalse: [traceModalities addAll: (eachModality echo echoValues)]
			].
			traceModalities asArray
		]! !

!Minerva methodsFor: 'settings' stamp: 'JohanBriglia 9/5/2013 15:25'!
startWith: aProbe

	"a Minerva needs at least one trace to run
	This method provide aProbe as a (or several) standart Trace(s) without gathering"

	| probes |
	
	(aProbe at: 1) isArray
		ifTrue: [probes := aProbe]
		ifFalse: [probes := {aProbe}].
	probe numberOfModalities: (probes at: 1) size.
	echo numberOfModalities: (probes at: 1) size.
	
	probes do: [ :eachProbe |
		traces tracesValues add: (
			Trace new newWith: (eachProbe asArray) gathered: (1 to: eachProbe size))].! !

!Minerva methodsFor: 'gears' stamp: 'JohanBriglia 7/1/2013 17:12'!
testProbe: aProbe

	"test a probe and return an Array with fluence, echo modalities and gathering"
	
	Minerva learn: false.
	
	^Array with: ({ self injectProbe: aProbe})
			with: (self echo echoValues)
			with: (self echo gathering)! !

!Minerva methodsFor: 'gears' stamp: 'JohanBriglia 5/22/2013 15:12'!
testProbes: aBunchOfProbes

	"test several probes and return an Array with fluence, echo modalities and gathering for each"
	
	| results |
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Testing' 
		at: Display center from: 0 to: aBunchOfProbes size
		during: [ :bar |
			aBunchOfProbes doWithIndex: [:each :index |
				bar value: index.
  				results add: (self testProbe: each)]].
	^results! !

!Minerva methodsFor: 'objects' stamp: 'JohanBriglia 8/2/2012 13:40'!
traces

	"The variable traces of the current Minerva containing an object Traces"

	^traces ifNil: [traces := Traces new]! !

Object subclass: #MinervaExperiments
	instanceVariableNames: 'mimi differenciationThreshold'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

MinervaExperiments class
	instanceVariableNames: 'indexOfRandomOrder'!

!MinervaExperiments commentStamp: 'JohanBriglia 9/5/2013 14:48' prior: 0!
Copr. Johan BRIGLIA 2013

johan.briglia@gmail.com

This file is part of MetaMinerva

MetaMinerva is a computer program whose purpose is to modelize the
human memory according to fractal appariement theories. MetaMinerva
is an improvement of Hintzman's Minerva2 ideas (1986) and do not use
any part of the original software.

MetaMinerva is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
http://www.cecill.info

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms.!

MinervaExperiments class
	instanceVariableNames: 'indexOfRandomOrder'!

MinervaExperiments subclass: #CuedRecall
	instanceVariableNames: 'numberOfExperimentations numberOfModalities valueToReach'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!CuedRecall methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:12'!
evolutionOf: someResults 

	"return the mean and standart deviation, a Pearson test and some Student tests of the results"

	| results evolutionStudents |
	
	results := self likelinessOf: someResults.
	evolutionStudents := (1 to: 4) collect: [:index |
							self studentTestOf: (results collect: [:each | 
								{each at: index. each at: (index +1)}])].
		
	^{self stringMeanOf: results. self pearsonTestOf: results. evolutionStudents}! !

!CuedRecall methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:21'!
experiment

	"integrate 5 random probes, then integrate a significant probe (so there is no null value) four times
	  between each integration of probeToTest, a truncatedProbe is tested (i.e. 5 times)
	  then the likelinesses between the studied part of the truncated probe echo and the studied part of the probeToTest are calculated
	  this is how cued recall is tested"

	| probesToIntegrate probeToTest truncatedProbe dataToExperiment |
	
	dataToExperiment := OrderedCollection new.
	
	probesToIntegrate := (self randomProbes: 5 with: numberOfModalities) asOrderedCollection.
	probeToTest := (self randomSignificantProbeWith: numberOfModalities) asOrderedCollection.
		valueToReach := probeToTest first.
	truncatedProbe := probeToTest copy.
		truncatedProbe at: 1 put: 0.
	dataToExperiment add: {probesToIntegrate. {truncatedProbe}}.

	(1 to: 4) do: [ :numberOfPresentation |
		dataToExperiment add: {{probeToTest}. {truncatedProbe}}].
	
	^{dataToExperiment}! !

!CuedRecall methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:22'!
initialize

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ;
		numberOfModalities ;
		valueToReach ! !

!CuedRecall methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:25'!
likelinessOf: someResults

	"collect likelinesses of results"

	^someResults collect: [:eachExperiment |
		(eachExperiment second) collect: [:eachRoundValue |
			self likelinessBetween: (eachExperiment first) and: eachRoundValue]]! !

!CuedRecall methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:25'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]
	! !

!CuedRecall methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:27'!
numberOfModalities

	"number of modalities used for this experiment"

	^numberOfModalities ifNil: [numberOfModalities := 5]! !

!CuedRecall methodsFor: 'Stats' stamp: 'JohanBriglia 9/5/2013 16:28'!
recallOf: aListOfResults

	"collect the two values used to calculate the correct answer level"
	
	^{valueToReach.
		(aListOfResults first) collect: [ :eachRound | eachRound second first second first]}! !

!CuedRecall methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:31'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self recallOf: (self run: (self experiment)))].
			self clean].
		
	^self evolutionOf: results! !

!CuedRecall methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:33'!
valueToReach 

	"value to reach by the model"

	^valueToReach ifNil: [valueToReach := 0]! !

MinervaExperiments subclass: #FURIG
	instanceVariableNames: 'numberOfExperimentations'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!FURIG methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:34'!
differenciationOf: someResults

	"perform the tests needed"
		
	| furig pekig |
	
	furig := someResults collect: [:each | each first].
	pekig := someResults collect: [:each | each second].
	
	^{{self stringMeanOf: furig. self stringMeanOf: pekig}.
	  self studentTestBetween: furig and: pekig.
		self studentTestBetween: (furig abs) and: (pekig abs)}! !

!FURIG methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:41'!
experiment

	"whitlesea experiment about activation and dissociation
	create 5 different probes to integrate, 1 probe different from them (pekig), and 1 probe as a prototype of them (furig)
	this experiment integrate the five first probes, then test furig and pekig in order to make a comparison"

	| probes episods furig pekig |
	
	probes := self randomDifferentProbes: 6 with: 7.
	
	episods := (1 to: 5) collect: [:each | probes at: each].
	
	furig := self meanOf: episods.
	pekig := probes last.
	
	^{{{episods. {furig. pekig}}}}! !

!FURIG methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:42'!
fluencesOf: someResults

	"get the pekig and furig fluences in the results"

	^{someResults first first second first first first. someResults first first second second first first}! !

!FURIG methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:22'!
initialize

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ! !

!FURIG methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:25'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!FURIG methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:31'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self fluencesOf: (self run: (self experiment)))].
			self clean].
	
	^self differenciationOf: results! !

MinervaExperiments subclass: #GlobalAppariement
	instanceVariableNames: 'numberOfExperimentations knowledge learningTask coloredProbes coloredWords'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!GlobalAppariement methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:43'!
evaluationOf: someResults

	"get the values needed in order to perform the needed tests on them"

	| behavior fluences oldBlack oldYes oldNo newBlack newYes newNo yesColor noColor blackColor |
	
	behavior := OrderedCollection new.
	fluences := OrderedCollection new.
	oldBlack := OrderedCollection new.
	oldYes := OrderedCollection new.
	oldNo := OrderedCollection new.
	newBlack := OrderedCollection new.
	newYes := OrderedCollection new.
	newNo := OrderedCollection new.
	yesColor := OrderedCollection new.
	noColor := OrderedCollection new.
	blackColor := OrderedCollection new.
	
	someResults do: [:eachExperiment |
		eachExperiment do: [:each |
			behavior add: (each first).
			fluences add: (each second)].
		oldBlack add: (eachExperiment first first).
		oldYes add: (eachExperiment second first).
		oldNo add: (eachExperiment third first).
		newBlack add: (eachExperiment fourth first).
		newYes add: (eachExperiment fifth first).
		newNo add: (eachExperiment sixth first).
		yesColor add: (eachExperiment seventh first).
		noColor add: (eachExperiment eighth first).
		blackColor add: (eachExperiment ninth first)].
	
	^{{self meanOf: oldBlack. self meanOf: oldYes. self meanOf: oldNo. 
			self meanOf: newBlack. self meanOf: newYes. self meanOf: newNo.
			self meanOf: blackColor. self meanOf: yesColor. self meanOf: noColor} roundTo: 0.01.
		{self standartDeviationOf: oldBlack. self standartDeviationOf: oldYes. self standartDeviationOf: oldNo. 
			self standartDeviationOf: newBlack. self standartDeviationOf: newYes. self standartDeviationOf: newNo.
			self standartDeviationOf: blackColor. self standartDeviationOf: yesColor. self standartDeviationOf: noColor} roundTo: 0.01.
			
	{self pearsonTestBetween: behavior and: fluences.
	self studentTestBetween: oldBlack and: newBlack.
	self studentTestBetween: oldBlack and: oldYes.
	self studentTestBetween: oldBlack and: oldNo.
	self studentTestBetween: oldYes and: oldNo.
	self studentTestBetween: newBlack and: newYes.
	self studentTestBetween: newBlack and: newNo.
	self studentTestBetween: newYes and: newNo.
	self studentTestBetween: blackColor and: yesColor.
	self studentTestBetween: blackColor and: noColor.
	self studentTestBetween: yesColor and: noColor.
	self studentTestBetween: oldYes and: newYes.
	self studentTestBetween: oldNo and: newNo}.
	
	{self meanOf: (self booleanisationOf: (oldBlack collect: [:each | each > 0])).
	self meanOf: (self booleanisationOf: (oldYes collect: [:each | each > 0])).
	self meanOf: (self booleanisationOf: (oldNo collect: [:each | each > 0])).
	self meanOf: (self booleanisationOf: (newBlack collect: [:each | each < 0])).
	self meanOf: (self booleanisationOf: (newYes collect: [:each | each < 0])).
	self meanOf: (self booleanisationOf: (newNo collect: [:each | each < 0]))} roundTo: 0.01.}! !

!GlobalAppariement methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:49'!
experiment 

	"this is an experiment about multi-modal integration in appariement remembering
	integrate three tasks (knowledge about the task, word learning task, and action coloration)
	then test the emergence of appariement when remembering"

	self variables.

	^{{{
	
	self randomOrderOf: 
	( knowledge, 
	learningTask, 
	(self repeatProbes: coloredProbes)). 
	
	coloredWords}}}! !

!GlobalAppariement methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:22'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations! !

!GlobalAppariement methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:25'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"
		
	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!GlobalAppariement methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:50'!
reactionsOf: someResults

	"collect the motor reactions of the model responses"

	^someResults first first second collect: [:eachProbe |
		{eachProbe second first. eachProbe first first}]! !

!GlobalAppariement methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:31'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self reactionsOf: (self run: (self experiment)))].
			self clean].
		
	^self transcript: (self evaluationOf: results)! !

!GlobalAppariement methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:50'!
transcript: someResults 

	"write the results in Transcript (because there are lots of them)"

	Transcript clear.
	Transcript show: 'Pearson test between action and fluence :' ; cr ; show: '   ' ; show: (someResults third first) ; cr ; cr.
	
	Transcript show: 'Results means :  black |   yes  | no' ; cr.
	Transcript show: '              Old :     ' ; show: (self fitRounded: (someResults first first)) ; show: ' | ' ; 
		show: (self fitRounded: (someResults first second)) ; show: ' | ' ; show: (self fitRounded: (someResults first third)) ; cr.
	Transcript show: '             New :     ' ; show: (self fitRounded: (someResults first fourth)) ; show: ' | ' ; 
		show: (self fitRounded: (someResults first fifth)) ; show: ' | ' ; show: (self fitRounded: (someResults first sixth)) ; cr.
	Transcript show: ' Color Effect :     ' ; show: (self fitRounded: (someResults first seventh)) ; show: ' | ' ; 
		show: (self fitRounded: (someResults first eighth)) ; show: ' | ' ; show: (self fitRounded: (someResults first ninth)) ; cr ; cr.
	
	Transcript show: 'Results stdev :   black |   yes  | no' ; cr.
	Transcript show: '              Old :     ' ; show: (self fitRounded: (someResults second first)) ; show: ' | ' ; 
		show: (self fitRounded: (someResults second second)) ; show: ' | ' ; show: (self fitRounded: (someResults second third)) ; cr.
	Transcript show: '             New :     ' ; show: (self fitRounded: (someResults second fourth)) ; show: ' | ' ; 
		show: (self fitRounded: (someResults second fifth)) ; show: ' | ' ; show: (self fitRounded: (someResults second sixth)) ; cr.
	Transcript show: ' Color Effect :     ' ; show: (self fitRounded: (someResults second seventh)) ; show: ' | ' ; 
		show: (self fitRounded: (someResults second eighth)) ; show: ' | ' ; show: (self fitRounded: (someResults second ninth)) ; cr ; cr.
	
	Transcript show: 'Statistic tests :' ; cr.
	Transcript show: '   Old-Black / New-Black : ' ; show: (someResults third second) ; cr.
	Transcript show: '      Old-Black / Old-Yes : ' ; show: (someResults third third) ; cr.
	Transcript show: '        Old-Black / Old-No : ' ; show: (someResults third fourth) ; cr.
	Transcript show: '          Old-Yes / Old-No : ' ; show: (someResults third fifth) ; cr.
	Transcript show: '    New-Black / New-Yes : ' ; show: (someResults third sixth) ; cr.
	Transcript show: '     New-Black / New-No : ' ; show: (someResults third seventh) ; cr.
	Transcript show: '        New-Yes / New-No : ' ; show: (someResults third eighth) ; cr.
	Transcript show: '                   Black / Yes : ' ; show: (someResults third ninth) ; cr.
	Transcript show: '                     Black / No : ' ; show: (someResults third at: 10) ; cr.
	Transcript show: '                       Yes / No : ' ; show: (someResults third at: 11) ; cr.
	Transcript show: '          Old-Yes / New-Yes : ' ; show: (someResults third at: 12) ; cr.
	Transcript show: '          Old-No / New-No : ' ; show: (someResults third at: 13) ; cr ; cr.
	
	Transcript show: 'Correst answers :' ; cr.
	Transcript show: ' Old Black : ' ; show: (someResults fourth first) ; cr.
	Transcript show: '   Old Yes : ' ; show: (someResults fourth second) ; cr.
	Transcript show: '     Old No : ' ; show: (someResults fourth third) ; cr.
	Transcript show: 'New Black : ' ; show: (someResults fourth fourth) ; cr.
	Transcript show: '  New Yes : ' ; show: (someResults fourth fifth) ; cr.
	Transcript show: '    New No : ' ; show: (someResults fourth sixth) ; cr ; cr.
	
	
	Transcript show: 'BR neutre : ' ; show: (someResults fourth first + (someResults fourth fourth) / 2) ; cr.
	Transcript show: '     BR coh : ' ; show: (someResults fourth second + (someResults fourth sixth) / 2) ; cr.
	Transcript show: '  BR incoh : ' ; show: (someResults fourth third + (someResults fourth fifth) / 2) ; cr.
	Transcript show: 'MR neutre : ' ; show: (1 - (someResults fourth first) + (1 - (someResults fourth fourth)) / 2) ; cr.
	Transcript show: '     MR coh : ' ; show: (1 - (someResults fourth second) + (1 - (someResults fourth sixth)) / 2) ; cr.
	Transcript show: '  MR incoh : ' ; show: (1 - (someResults fourth third) + (1 - (someResults fourth fifth)) / 2) ; cr ; cr.! !

!GlobalAppariement methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:53'!
variables

	"set the random values of colors and words to create the probes needed for integration and testing"

	| yes yesButton no noButton neutral neutralButton colors blue purple black noColor words noWord |

	yes := #(1).
		yesButton := #(1).
	no := #(-1).
		noButton := #(-1).
	neutral := #(0).
		neutralButton := #(0).
	
	colors := self randomDifferentProbes: 3 with: 3.
		blue := colors first.
		purple := colors second.
		black := colors third.
		noColor := #(0 0 0).
		
	words := self randomDifferentProbes: 6 with: 6.
		learningTask := self randomOrderOf: {
			yesButton, yes, noColor, (words first).
			yesButton, yes, noColor, (words second).
			yesButton, yes, noColor, (words third)}.
		noWord := #(0 0 0 0 0 0).
	
	knowledge := self randomOrderOf: {
		yesButton, yes, noColor, noWord.
		noButton, no, noColor, noWord}.
		
	coloredProbes := self randomOrderOf: {
		neutralButton, yes, blue, noWord.
		neutralButton, no, purple, noWord}.
	
	coloredWords := {
		neutralButton, neutral, black, (words first).
		neutralButton, neutral, blue, (words second).
		neutralButton, neutral, purple, (words third).
		neutralButton, neutral, black, (words fourth).
		neutralButton, neutral, blue, (words fifth).
		neutralButton, neutral, purple, (words sixth).
		neutralButton, neutral, blue, noWord.
		neutralButton, neutral, purple, noWord.
		neutralButton, neutral, black, noWord}.! !

MinervaExperiments subclass: #InterferenceTask
	instanceVariableNames: 'numberOfExperimentations'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!InterferenceTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:54'!
evaluationOf: someResults 

	"calculate the needed tests in order to evaluate the results"

	| control interfered quotient |
	
	control := OrderedCollection new.
	interfered := OrderedCollection new.
	
	someResults do: [:eachExperiment |
		control add: eachExperiment first.
		interfered  add: eachExperiment second].
	
	quotient := self meanOf: (
					self booleanisationOf: (
					(1 to: (control size)) collect: [:index | 
								(control at: index) > (interfered at: index)])).
	
	^{self stringMeanOf: control. self stringMeanOf: interfered.
	self studentTestBetween: control and: interfered.
	quotient roundTo: 0.01}! !

!InterferenceTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:56'!
experiment 

	"set a learningTask and an interferenceTask
	the first one uses only the first half of modalities
	the second one uses the second half.
	then test the learning task before and after the interferenceTask"

	| learningTask interferenceTask |
	
	learningTask := (self randomProbes: 4 with: 5) collect: [:each | each, #(0 0 0 0 0)].
	interferenceTask := (self randomProbes: 4 with: 5) collect: [:each | #(0 0 0 0 0), each].
	
	^{{{learningTask. learningTask}. {interferenceTask. learningTask}}}! !

!InterferenceTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:56'!
fluencesOf: someResults 

	"collect the needed fluences from results"

	^(someResults first) collect: [:eachRound |
		self meanOf: (
		eachRound second collect: [:eachProbe | eachProbe first first])]! !

!InterferenceTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:22'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ! !

!InterferenceTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:31'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!InterferenceTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:31'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self fluencesOf: (self run: (self experiment)))].
			self clean].
	
	^self evaluationOf: results! !

!MinervaExperiments class methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 7/11/2013 13:31'!
indexOfRandomOrder

	^indexOfRandomOrder! !

!MinervaExperiments class methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 7/11/2013 13:34'!
indexOfRandomOrder: aCollection

	indexOfRandomOrder := aCollection ! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 9/5/2013 15:34'!
areDifferent: aProbe and: anOtherProbe

	"return a boolean : true if the two probes are different (from differenciationThreshold)"

	^(self likelinessBetween: aProbe and: anOtherProbe) < differenciationThreshold 
		! !

!MinervaExperiments methodsFor: 'Ajustments' stamp: 'JohanBriglia 9/5/2013 15:36'!
booleanisationOf: aCollection

	"redundant method turning each boolean value of a/some list(s) into 0/1 values
	  it is used to facilitate statistic tests"

	^aCollection collect: [:each | | value |
		(each isCollection)
			ifTrue: [value := self booleanisationOf: each]
			ifFalse: [each ifTrue: [value := 1] ifFalse: [value := 0]].
		value]! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 9/5/2013 15:36'!
clean

	"Erase the current minerva (and all sub-minervas)"

	mimi := Minerva new.
	Smalltalk garbageCollect! !

!MinervaExperiments methodsFor: 'Ajustments' stamp: 'JohanBriglia 9/5/2013 15:37'!
contextualTracesOf: aMinerva

	"collect and return all important values of aMinerva contextual traces"

	^ (1 to: (aMinerva contextualTraces size)) collect: [ :i |
		{ aMinerva traces similarities at: i.
		   aMinerva contextualTraces at: i.
		  (aMinerva traces tracesValues at: i) gathering } ]! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 9/5/2013 15:40'!
differenciationThreshold

	"value used as threshold from with two probes are considered different
	  standart value is 0.2 : as mean of two random probes likeliness - standartDeviation of them
	  0.33 - 0.13 = 0.2"

	^differenciationThreshold ifNil: [differenciationThreshold := 0.2]! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 9/5/2013 15:40'!
differenciationThreshold: aFloat

	"set aFloat  as differenciationThreshold"

	differenciationThreshold := aFloat ! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 15:41'!
fisherTestBetween: aFirstPopulation and: anOtherPopulation 

	"perform a Fisher test between these two populations"

	| variances dfA dfB fTest |
	
	variances := {self varianceOf: aFirstPopulation. self varianceOf: anOtherPopulation}.

	(variances = {variances max. variances min})
		ifTrue: [dfA := aFirstPopulation size - 1.
				dfB := anOtherPopulation size - 1]
		ifFalse: [dfA := aFirstPopulation size - 1.
				dfB := anOtherPopulation size - 1].
			
	fTest := (variances max) / (variances min).
	
	^'F(', dfA asString, ',', dfB asString, ') = ', (fTest roundTo: 0.01) asString! !

!MinervaExperiments methodsFor: 'Ajustments' stamp: 'JohanBriglia 9/5/2013 15:42'!
fitRounded: aFloat

	"Round a float or an integer at 10^-2 as string
	  Used within the Transcript to show results"
	
	| roundedNumber |
	
	(aFloat = 0) ifTrue: [^' 0.00'].
	(aFloat < 0) ifTrue: [roundedNumber := '-']
		ifFalse: [roundedNumber := ' '].
	
	roundedNumber := 
		roundedNumber asString , aFloat integerPart asInteger abs asString , '.' , (aFloat fractionPart * 10) abs integerPart asInteger asString ,
		((aFloat fractionPart * 10) fractionPart * 10) abs integerPart asInteger asString.
		
	^roundedNumber! !

!MinervaExperiments methodsFor: 'graphics' stamp: 'JohanBriglia 11/23/2012 21:25'!
graphicGatheringOf: aTrace with: aGathering

	"change aTrace modalities in a string with values gathered"
	
	| graphicalGathering cursor|
	graphicalGathering := aTrace.
	cursor := -1.
	
	(1 to: (aGathering last)) do: [ :each |
		graphicalGathering at: (cursor + 3) put: $[ .
		cursor := cursor + ((aGathering count: [ :g | g = each]) * 11).
		graphicalGathering at: cursor put: $]
	].
	^graphicalGathering! !

!MinervaExperiments methodsFor: 'graphics' stamp: 'JohanBriglia 9/5/2013 15:43'!
graphicModalitiesOf: aTrace

	"change aTrace modalities in a string"
	
	| graphicModalities |
	
	graphicModalities := ''.
	
	(aTrace) do: [ :each |
		graphicModalities := graphicModalities asString , '   ' , (self fitRounded: each) , '   '
	].
	^graphicModalities! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 9/5/2013 15:44'!
initialize 

	"initialize the object and its variable"

	super initialize.
	self differenciationThreshold ! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 9/5/2013 15:46'!
integrate: aBunchOfProbes

	"integrate aBunchOfProbes in the current minerva"

	| probes |
	
	(aBunchOfProbes at: 1) isCollection
		ifTrue: [probes := aBunchOfProbes] 
		ifFalse: [probes := {aBunchOfProbes}].
		
	(mimi traces tracesValues size = 0)
		ifTrue: [mimi startWith: (probes at: 1).
				(probes size > 1)
					ifTrue: [mimi integrateProbes: (
								(2 to: probes size) collect: [:index | probes at: index])]]
		ifFalse: [mimi integrateProbes: probes]
	! !

!MinervaExperiments methodsFor: 'graphics' stamp: 'JohanBriglia 9/5/2013 15:47'!
integrateShowTranscript: aProbe

	"integrate probe(s) in the current minerva then show the results in the Transcript"

	Minerva learn: true.

	(aProbe at: 1) isArray
	ifTrue: [ "If there are several probes"
		self showSomeTestsWith: aProbe inducing: (self mimi integrateProbes: aProbe)]
	ifFalse: [ "If there is just one Probe"
		self showATestInducing: (self mimi integrateProbe: aProbe)
			in: (self contextualTracesOf:  (self mimi))
			with: (self mimi probe probeValues)]! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 9/5/2013 15:48'!
isDifferent: aProbe from: aListOfProbes

	"compare two probes and return a boolean about their difference"

	aListOfProbes do: [:eachProbe |
		(self areDifferent: aProbe and: eachProbe)
			ifFalse: [^false]].
		
	 ^true! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 15:48'!
jarqueBeraTestOf: aPopulation

	"perform a Jarque Bera test"

	| n s2 k jb |
	
	n := aPopulation size.
	s2 := (self skewnessOf: aPopulation) squared.
	k := self kurtosisOf: aPopulation.
	
	jb := (n/6) * (s2 + ((k - 3) squared / 4)).
	
	^jb roundTo: 0.01! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 15:49'!
kurtosisOf: aPopulation

	"perform a kurtosis test"

	| mean n s kurtosis |

	n := aPopulation size.
	s := self sampleDeviationOf: aPopulation.
	mean := self meanOf: aPopulation.

	kurtosis := (self meanOf: (aPopulation collect: [:xi | (xi - mean) raisedTo: 4])) /
				((self meanOf: (aPopulation collect: [:xi | (xi - mean) raisedTo: 2])) squared).
	
	^kurtosis roundTo: 0.01! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 9/5/2013 15:52'!
likelinessBetween: aProbe and: anOtherProbe

	"return a value about likeliness between two probes from their mutual distance
	  this value is in [-1 ; 1] and shows from total difference to total similarity
	  its mean is 0.33 (because there are lots more near probes than far probes) and its standard deviation is 0.13"

	| distance |
	
	distance := self meanOf: (
		(1 to: (aProbe asOrderedCollection size)) collect: [:index |
			((aProbe asOrderedCollection at: index) - (anOtherProbe asOrderedCollection at: index)) abs]).
		
	^(distance - 1) negated! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 15:52'!
meanOf: aListOfValues

	"perform a redundant mean of list(s)"

	^(aListOfValues inject: 0 into: [:each :sum | sum + each])
	/
	(aListOfValues size)! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 9/5/2013 15:53'!
mimi

	"variable and nickname of the current minerva"

	^mimi ifNil: [mimi := Minerva new]! !

!MinervaExperiments methodsFor: 'Ajustments' stamp: 'JohanBriglia 9/5/2013 15:54'!
normalizationOf: aCollection

	"perform a redundant center/reduce to aCollection"

	| probes |

	(aCollection first) isCollection
		ifTrue: [^aCollection collect: [:each | self normalizationOf: each]] 
		ifFalse: [probes := aCollection - (aCollection min).
				^probes / (probes max)]! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 15:26'!
pearsonTestBetween: aPopulation and: anOtherPopulation 

	"calculate a Pearson test between two populations"

	| x y xMean yMean n covariance xDeviation yDeviation r |
	
	x := aPopulation.
	y := anOtherPopulation.
	
	xMean := self meanOf: x.
	yMean := self meanOf: y.
	n := x size.
	
	covariance := (1 to: n) inject: 0 into: [:sum :i | 
					((x at: i) - xMean) * ((y at: i) - yMean) + sum].
	xDeviation := ((1 to: n) inject: 0 into: [:sum :i | 
					((x at: i) - xMean) squared + sum]) sqrt.
	yDeviation := ((1 to: n) inject: 0 into: [:sum :i | 
					((y at: i) - yMean) squared + sum]) sqrt.
				
	r := covariance / (xDeviation * yDeviation).
	
	^'R(', n asString, ') = ', (r roundTo: 0.01) asString ! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 15:28'!
pearsonTestOf: someObservations

	"simpler version to perform a Pearson test when the two populations are within each subject responses"

	| x y |
	
	x := OrderedCollection new.
	y := OrderedCollection new.
	
	someObservations do: [:eachExperiment |
		(1 to: (eachExperiment size)) do: [:index |
			x add: (eachExperiment at: index).
			y add: index]].
	
	^self pearsonTestBetween: x and: y! !

!MinervaExperiments methodsFor: 'shuffling' stamp: 'JohanBriglia 9/5/2013 15:54'!
randomDifferentProbes: probesNumber with: modalitiesNumber

	"return a choosen number of probes with modalitiesNumber in each
	  These are random probes with differenciationThreshold likeliness between them : they are different"

	| probes |
	
	probes := {self randomSignificantProbeWith: modalitiesNumber} asOrderedCollection.
	
	(probesNumber > modalitiesNumber) ifTrue: [Smalltalk error: 'not enough modalities'].
	
	UIManager default 
		displayProgress: 'Shuffling probes' 
		at: Display center from: 0 to: probesNumber
		during: [ :bar |  bar value: 1.
	
	(2 to: probesNumber) do: [:index | | randomProbe counter |
		counter := 1.
		randomProbe := self randomSignificantProbeWith: modalitiesNumber.
		[counter := counter + 1. self isDifferent: randomProbe from: probes]
			whileFalse: [randomProbe := self randomSignificantProbeWith: modalitiesNumber.
							(counter = 100000) ifTrue: [^self randomDifferentProbes: probesNumber with: modalitiesNumber]].
		bar value: index.
		probes add: randomProbe]].

	^probes! !

!MinervaExperiments methodsFor: 'shuffling' stamp: 'JohanBriglia 9/5/2013 15:55'!
randomOrderOf: aCollection

	"return aCollection with its items randomly ordered.
	  made for statistical purpose"

	| bag randomedCollection indexes randomOrderIndex |
	
	bag := Bag new.
	randomedCollection := OrderedCollection new.
	indexes := 1 to: (aCollection size).
	randomOrderIndex := OrderedCollection new.

	indexes do: [:x | | randomIndex |
		randomIndex := indexes atRandom.
		[bag includes: randomIndex]
			whileTrue: [randomIndex := indexes atRandom].
		bag add: randomIndex.
		randomedCollection add: (aCollection at: randomIndex).
		randomOrderIndex add: randomIndex].
	
	MinervaExperiments indexOfRandomOrder: randomOrderIndex.
	
	^randomedCollection! !

!MinervaExperiments methodsFor: 'shuffling' stamp: 'JohanBriglia 9/5/2013 15:56'!
randomProbeWith: modalitiesNumber

	"return a random collection of values between -1 and 1"

	^(1 to: modalitiesNumber) collect: [:P | self randomValue]! !

!MinervaExperiments methodsFor: 'shuffling' stamp: 'JohanBriglia 7/1/2013 17:30'!
randomProbes: probesNumber with: modalitiesNumber

	"send probesNumber random probes with modalitiesNumber modalities each"

	^(1 to: probesNumber) collect: [:D |
		self randomProbeWith: modalitiesNumber].! !

!MinervaExperiments methodsFor: 'shuffling' stamp: 'JohanBriglia 9/5/2013 16:00'!
randomSignificantProbeWith: modalitiesNumber

	"return a random probe
	each of these probes has significant modalities values
	i.e. not too close to 0 (actually not between -0.33 and 0.33)"

	^(1 to: modalitiesNumber) collect: [:P | self randomSignificantValue]! !

!MinervaExperiments methodsFor: 'shuffling' stamp: 'JohanBriglia 9/5/2013 16:00'!
randomSignificantProbes: probesNumber with: modalitiesNumber

	"return a collection of random significant probes"

	^(1 to: probesNumber) collect: [:D |
		self randomSignificantProbeWith: modalitiesNumber].! !

!MinervaExperiments methodsFor: 'shuffling' stamp: 'JohanBriglia 9/5/2013 16:00'!
randomSignificantValue

	"send a random value E([-1 ; -0.33]U[0.33 ; 1])"

	| significantValue |
	
	significantValue := (101 - (68 atRandom) / 100) roundTo: 0.01.

	(2 atRandom = 1)
		ifTrue: [^significantValue]
		ifFalse: [^significantValue negated]! !

!MinervaExperiments methodsFor: 'shuffling' stamp: 'JohanBriglia 5/22/2013 22:31'!
randomValue

	"send a random value between -1.00 and 1.00"

	^ (201 atRandom - 101 / 100) roundTo: 0.01! !

!MinervaExperiments methodsFor: 'Ajustments' stamp: 'JohanBriglia 9/5/2013 16:01'!
repeat: anInteger probes: aListOfProbes 

	"repeat anInteger times each probe from aListOfProbes"

	| probes |
	
	probes := OrderedCollection new.
	
	aListOfProbes do: [:each | 
		(1 to: anInteger) do: [:x | probes add: each]].
	
	^probes ! !

!MinervaExperiments methodsFor: 'Ajustments' stamp: 'JohanBriglia 9/5/2013 16:02'!
repeatProbes: aListOfProbes 

	"repeat two times each probe from aListOfProbes"

	| probes |
	
	probes := OrderedCollection new.
	
	aListOfProbes do: [:each | probes addAll: {each. each}].
	
	^probes ! !

!MinervaExperiments methodsFor: 'Settings' stamp: 'JohanBriglia 5/28/2013 14:41'!
run: listOfProbes

	"run the experiments and send a list with several couples tests/echoes"
	
	| results |
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Running experiments' 
		at: Display center from: 0 to: listOfProbes size
		during: [ :bar |
			listOfProbes doWithIndex: [:eachMinerva :index | |minervaResults|
				minervaResults := OrderedCollection new.
				bar value: index.
				self clean.
				eachMinerva do: [:eachRound |
					self integrate: (eachRound at: 1).
 	 				minervaResults add: {eachRound at: 2. mimi testProbes: (eachRound at: 2)}].
				results add: (minervaResults asArray)]].
	^results! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 16:05'!
sampleDeviationOf: aPopulation

	"return the sample standart deviation of aPopulation"

	^(self sampleVarianceOf: aPopulation) sqrt! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 16:05'!
sampleVarianceOf: aPopulation

	"return the sample variance of aPopulation"

	| mean |

	mean := self meanOf: aPopulation.

	^(aPopulation inject: 0 into: [:sum :x | (x - mean) squared + sum]) / (aPopulation size - 1)! !

!MinervaExperiments methodsFor: 'graphics' stamp: 'JohanBriglia 9/5/2013 16:03'!
showATestInducing: anEcho in: someTraces with: aProbe

	"show in Transcript results from an experiment"

	Transcript clear ;
		show: '   Probe :        ' ;
		show: (self graphicModalitiesOf: aProbe) ; cr ; cr ;
		
		show: 'Similarities |       Contextual Traces :' ; cr.
	someTraces do: [ :each |
		Transcript show: ((self graphicModalitiesOf: {each at: 1}) , '   ||   ' , 
		(self graphicGatheringOf: (self graphicModalitiesOf: (each at: 2)) with: (each at: 3))) ; cr].
	
	Transcript cr ; show: '  Fluence    |      Echo :' ; cr ;
		show: ((self graphicModalitiesOf: (anEcho at: 1)) , '   ||   ' , 
		(self graphicGatheringOf: (self graphicModalitiesOf: (anEcho at: 2)) with: (anEcho at: 3))).
		
	Transcript cr ; cr ; show: 'Minerva instances : ' ; show: (Minerva allInstances size) ; cr ;
		show: 'Total number of Traces : ' ; show: (Trace allInstances size) ; cr! !

!MinervaExperiments methodsFor: 'graphics' stamp: 'JohanBriglia 9/5/2013 16:04'!
showSomeTestsWith: someProbes inducing: someEchos

	"show in Transcript results from several experiments"

	Transcript clear ; show: ' Probes :' ; cr.
	someProbes do: [ :each |
		Transcript show: '                      ' ;
		show: (self graphicModalitiesOf: each) ; cr].
	
	Transcript cr ; show: '  Fluences  |      Echos :' ; cr.
	someEchos do: [ :each |
		Transcript show: ((self graphicModalitiesOf: (each at: 1)) , '   ||   ' , 
		(self graphicGatheringOf: (self graphicModalitiesOf: (each at: 2)) with: (each at: 3))) ; cr].
	
	Transcript cr ; show: 'Minerva instances : ' ; show: (Minerva allInstances size) ; cr ;
		show: 'Total number of Traces : ' ; show: (Trace allInstances size) ; cr! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 16:04'!
skewnessOf: aPopulation

	"perform a Skewness test of aPopulation"

	| mean n s skewness |

	n := aPopulation size.
	s := self sampleDeviationOf: aPopulation.
	mean := self meanOf: aPopulation.

	skewness := (aPopulation inject: 0 into: [:sum :xi | ((xi - mean) raisedTo: 3) + sum]) / ((n - 1) * (s raisedTo: 3)).
	
	^skewness roundTo: 0.01! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 16:05'!
standartDeviationOf: aPopulation

	"return the standart deviation of aPopulation"

	^(self varianceOf: aPopulation) sqrt! !

!MinervaExperiments methodsFor: 'Ajustments' stamp: 'JohanBriglia 9/5/2013 16:07'!
stringMeanOf: aCollection

	"return a redundant list of results (mean and standart deviation) as string
	something like '0.33(0.13)'"

	(aCollection first isCollection)
		ifTrue: [^(1 to: (aCollection first size)) collect: [:index |
					self stringMeanOf: 
						(aCollection collect: [:eachExperiment | eachExperiment at: index])]]
		ifFalse: [^((self meanOf: aCollection) roundTo: 0.001) asString, '(', ((self standartDeviationOf: aCollection) roundTo: 0.01) asString, ')']! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 16:08'!
studentTestBetween: aFirstPopulation and: anOtherPopulation

	"perform a Student test between a couple of populations"

	| nA nB df varA varB meanA meanB groupsDifference intergroupDeviation studentT |
	
	nA := aFirstPopulation size.
	nB := anOtherPopulation size.
	df := nA + nB - 2.
	varA := self varianceOf: aFirstPopulation.
	varB := self varianceOf: anOtherPopulation.
	meanA := self meanOf: aFirstPopulation.
	meanB := self meanOf: anOtherPopulation.
	
	groupsDifference := (meanA - meanB) abs.
	intergroupDeviation := (((nA * varA) + (nB * varB) / df) * ((1 / nA) + (1 / nB))) sqrt.
	
	studentT := (groupsDifference / intergroupDeviation) roundTo: 0.001.
	
	^(self fisherTestBetween: aFirstPopulation and: anOtherPopulation), ' ; T(', df asString, ') = ', studentT asString.! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 16:09'!
studentTestOf: someResults

	"uses an simplier form to calculate a Student test when the two populations are two items from each subject"

	| firstPopulation secondPopulation |
	
	firstPopulation := someResults collect: [:each | each first].
	secondPopulation := someResults collect: [:each | each second].

	^self studentTestBetween: firstPopulation and: secondPopulation! !

!MinervaExperiments methodsFor: 'graphics' stamp: 'JohanBriglia 9/5/2013 16:10'!
testShowTranscript: aProbe

	"first tests a/some probe(s) then shows it/them in Transcript"

	Minerva learn: false.

	(aProbe at: 1) isArray
	ifTrue: [ "If there are several probes"
		self showSomeTestsWith: aProbe inducing: (self mimi testProbes: aProbe)]
	ifFalse: [ "If there is just one Probe"
		self showATestInducing: (self mimi testProbe: aProbe)
			in: (self contextualTracesOf:  (self mimi))
			with: (self mimi probe probeValues)]! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 16:10'!
varianceOf: aPopulation

	"return the variance of aPopulation"

	| mean |

	mean := self meanOf: aPopulation.

	^self meanOf: (aPopulation collect: [:x | (x - mean) squared])! !

!MinervaExperiments methodsFor: 'statistics' stamp: 'JohanBriglia 9/5/2013 16:11'!
welchTestBetween: aFirstPopulation and: anOtherPopulation

	"perform a Welch test between two populations"

	| nA nB df varA varB meanA meanB groupsDifference intergroupDeviation welchT |
	
	meanA := self meanOf: aFirstPopulation.
	meanB := self meanOf: anOtherPopulation.
	nA := aFirstPopulation size.
	nB := anOtherPopulation size.
	varA := self varianceOf: aFirstPopulation.
	varB := self varianceOf: anOtherPopulation.
	
	df := ((varA / nA) + (varB / nB)) squared
			/
		(((varA / nA) squared / (nA - 1)) + ((varB / nB) squared / (nB - 1))).
	
	groupsDifference := (meanA - meanB) abs.
	intergroupDeviation := ((varA / (nA - 1)) + (varB / (nB - 1))) sqrt.
	
	welchT := (groupsDifference / intergroupDeviation) roundTo: 0.001.
	
	^'W(', (df roundTo: 0.01) asString, ') = ', welchT asString.! !

MinervaExperiments subclass: #Misremembering
	instanceVariableNames: 'numberOfExperimentations'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!Misremembering methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:57'!
evaluationOf: someResults 

	"perform the needed tests from results"
	
	^{{self meanOf: (someResults first). self standartDeviationOf: (someResults first)}.
	{self meanOf: (someResults second). self standartDeviationOf: (someResults second)}.
	{self pearsonTestOf: someResults first.
	self pearsonTestOf: someResults second}}! !

!Misremembering methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:57'!
evolutionOf: someResults 

	"collect the needed fluences and echoes in order to perform the tests"

	| fluenceEvolution echoesEvolution |
	
	fluenceEvolution := OrderedCollection new.
	echoesEvolution := OrderedCollection new.
	
	someResults do: [:eachExperiment |
		fluenceEvolution add: (eachExperiment first).
		echoesEvolution add: (eachExperiment second)].
	
	^{fluenceEvolution. echoesEvolution}! !

!Misremembering methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:17'!
experiment

	"the misremembering task is about false recognition when a probe is likely to the others already learned.
	creates 4 categories and 4 different probes from each (wich will be integrated).
	then uses the last category to create the non-integrated probe to test.
	The 3 firsts categories probes are integrated, then the probe to test is tested between each presentation of the last category probes"

	| categories probes probesToIntegrate probeToTest |
	
	categories := self randomDifferentProbes: 4 with: 5.
		categories := categories collect: [:each | each / (each abs)].
		
	probesToIntegrate := (1 to: 3) collect: [:index |
		(self randomDifferentProbes: 4 with: 5) collect: [:eachProbe |
			eachProbe abs * (categories at: index)]].
	probesToIntegrate := self randomOrderOf: (probesToIntegrate first, probesToIntegrate second, probesToIntegrate third).
		
	probes := (self randomDifferentProbes: 5 with: 5) collect: [:eachProbe | eachProbe abs * (categories last)].
	probeToTest := {probes last}.
	
	^{{{probesToIntegrate. probeToTest}. {{probes first}. probeToTest}. {{probes second}. probeToTest}. {{probes third}. probeToTest}. {{probes fourth}. probeToTest}}}! !

!Misremembering methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:22'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ! !

!Misremembering methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:26'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!Misremembering methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:18'!
observationsOf: someResults 

	"collect the echoes and fluences of each presentation of the probe to test"

	| fluences echoesEvolution |
	
	fluences := OrderedCollection new.
	echoesEvolution := OrderedCollection new.
	
	(someResults first) do: [:each | | probe echo |
		probe := each first first.
		echo := each second first second.
		fluences add: (each second first first first).
		echoesEvolution add: (self likelinessBetween: probe and: echo)].
	
	^{fluences. echoesEvolution}! !

!Misremembering methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:32'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self observationsOf: (self run: (self experiment)))].
			self clean].
	
	^self evaluationOf: (self evolutionOf: results)! !

MinervaExperiments subclass: #PositionEffect
	instanceVariableNames: 'numberOfExperimentations numberOfProbes numberOfModalities'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!PositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:19'!
evolutionOf: someResults 

	"collect the echo and fluences results and perform the needed tests"

	| evolutionOfFluence evolutionOfEcho fluenceRecency echoRecency |
	
	evolutionOfFluence := someResults collect: [:each | each first].
	evolutionOfEcho := someResults collect: [:each | each second].
	
	fluenceRecency := someResults collect: [:eachExperiment |
					(2 to: numberOfProbes) collect: [:index |
						eachExperiment first at: index]].
	echoRecency := someResults collect: [:eachExperiment |
					(2 to: numberOfProbes) collect: [:index |
						eachExperiment second at: index]].
				
	^{self stringMeanOf: evolutionOfFluence. self stringMeanOf: evolutionOfEcho.
	self pearsonTestOf: fluenceRecency. self pearsonTestOf: echoRecency}! !

!PositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:26'!
experiment 

	"the position effect looks for a probe evolution depending on its position in a list.
	7 different probes are created, all of them but the first are integrated in 7 minervas in the same order.
	In each of them, the probe to test has a different position.
	Then the fluence and echo of the probe to test recognition are compared"

	| probes probeToTest probesToIntegrate |
	
	probes := self randomDifferentProbes: numberOfProbes with: numberOfModalities.
	probeToTest := probes first.
	probesToIntegrate := (2 to: numberOfProbes) collect: [:each | probes at: each].
	
	^(1 to: numberOfProbes) collect: [:each | | minervas counter |
		minervas := OrderedCollection new.
		counter := 1.
		(1 to: numberOfProbes) do: [:index |
			(each = index)
				ifTrue: [minervas add: probeToTest] 
				ifFalse: [minervas add: (probesToIntegrate at: counter).
						counter := counter + 1]].
		{{self repeatProbes: minervas. {probeToTest}}}]! !

!PositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:22'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ;
		numberOfProbes ;
		numberOfModalities ! !

!PositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:26'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!PositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:26'!
numberOfModalities 

	"number of modalities used in this experiment"

	^numberOfModalities ifNil: [numberOfModalities := 8]! !

!PositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:26'!
numberOfProbes 

	"number of probes used in this experiment"
		
	^numberOfProbes ifNil: [numberOfProbes := 7]! !

!PositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:27'!
resultsOf: someResults 

	"collect fluences and likelinesses of the results"

	| fluences likelinesses |
	
	fluences := someResults collect: [:eachMinerva |
					eachMinerva first second first first first].
				
	likelinesses := someResults collect: [:eachMinerva |
						self likelinessBetween: (eachMinerva first first first) 
							and: (eachMinerva first second first second)].
						
	^{fluences. likelinesses}! !

!PositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:31'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self resultsOf: (self run: (self experiment)))].
			self clean].
	
	^self evolutionOf: results! !

MinervaExperiments subclass: #PresentationOrder
	instanceVariableNames: 'numberOfExperimentations'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!PresentationOrder methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:28'!
deviationsOf: someResults 

	"collect echoes and fluences then perform the needed tests"

	| fluencesDev echoesDev |
	
	fluencesDev := self standartDeviationOf: (someResults collect: [:eachMinerva | 
					(eachMinerva first second) collect: [:eachProbe | eachProbe first first]]).
	echoesDev := self meanOf: (self standartDeviationOf: (someResults collect: [:eachMinerva |
					(eachMinerva first second) collect: [:eachProbe | eachProbe second]])).
				
	^{self meanOf: fluencesDev. self meanOf: echoesDev}! !

!PresentationOrder methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:29'!
experiment 

	"create 6 random probes with 6 modalities each.
	3 random orders of these probes are made to test their standart deviations"

	| probes orders minervas |
	
	probes := self randomProbes: 6 with: 6.
	orders := (1 to: 3) collect: [:each | self randomOrderOf: probes].
	
	minervas := orders collect: [:each | {{each. probes}}].
	
	^minervas ! !

!PresentationOrder methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:23'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ! !

!PresentationOrder methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:26'!
numberOfExperimentations

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!PresentationOrder methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:32'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self deviationsOf: (self run: (self experiment)))].
			self clean].
	
	^self stringMeanOf: results! !

MinervaExperiments subclass: #Primacy
	instanceVariableNames: 'numberOfExperimentations numberOfProbes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!Primacy methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:37'!
experiment 

	"in this experiment, random probes are integrated then tested in the same order.
	we are comparing here the fluence of the first probe and the fluences mean of the others
	in order to show the higher value of primacy"

	| probes |
	
	probes := self randomProbes: numberOfProbes with: (numberOfProbes + 1).
	
	^{{{probes. probes}}}! !

!Primacy methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:37'!
fluencesOf: someResults 

	"fluence of the first probe and the fluences mean of the others are collected"

	^{someResults first first second first first first. 
	self meanOf: ((2 to: numberOfProbes) collect: [:index |
			(someResults first first second at: index) first first])}! !

!Primacy methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:23'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ;
		numberOfProbes ! !

!Primacy methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:26'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!Primacy methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:38'!
numberOfProbes

	"number of probes used in this experiment"
		
	^numberOfProbes ifNil: [numberOfProbes := 5]! !

!Primacy methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:32'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self fluencesOf: (self run: (self experiment)))].
			self clean].
	
	^{self stringMeanOf: results.
	self studentTestOf: results.
	self pearsonTestOf: results}! !

MinervaExperiments subclass: #Priming
	instanceVariableNames: 'numberOfExperimentations'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!Priming methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:39'!
evolutionOf: someResults 

	"collect fluences and likelinesses and perform the needed tests"

	| fluences likelinesses |
	
	fluences := someResults collect: [:each | each first].
	likelinesses := someResults collect: [:each | each second].
	
	^{self stringMeanOf: fluences. self stringMeanOf: likelinesses.
	self studentTestOf: fluences. self studentTestOf: likelinesses.
	self pearsonTestOf: fluences. self pearsonTestOf: likelinesses}! !

!Priming methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:46'!
experiment 

	"this experiment compares the echo and fluence of a probe according to its recency.
	these values are higher if an element is more recent.
	Here, two minervas with the same probes (5 different ones) are used :
	one with the probe to test in the last position, one with this probe in the third position"

	| probes alternateProbes probeToTest |
	
	probes := self randomDifferentProbes: 5 with: 6.
	alternateProbes := {probes first. probes second. probes fifth. probes third. probes fourth}.
	probeToTest := {probes last}.
	
	^{{{alternateProbes. probeToTest}}.{{probes. probeToTest}}}! !

!Priming methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:23'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ! !

!Priming methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:26'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!Priming methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:47'!
resultsOf: someResults 

	"collect fluences and echo likelinesses in the results"

	| fluences likelinesses |
	
	fluences := someResults collect: [:eachMinerva |
					eachMinerva first second first first first].
				
	likelinesses := someResults collect: [:eachMinerva |
						self likelinessBetween: (eachMinerva first first first) 
							and: (eachMinerva first second first second)].
						
	^{fluences. likelinesses}! !

!Priming methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:32'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self resultsOf: (self run: (self experiment)))].
			self clean].
	
	^self evolutionOf: results! !

MinervaExperiments subclass: #Prototypicality
	instanceVariableNames: 'numberOfExperimentations numberOfprobes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!Prototypicality methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:48'!
evaluationsOf: someResults 

	"collect needed values from the results then perform the needed tests"

	| furigDistribution prototypeDistribution furigEvolution |
	
	prototypeDistribution := someResults collect: [:each | {each first. each second}].
	furigDistribution := someResults collect: [:each | {each second. each third abs}].
	
	furigEvolution := self meanOf: (self booleanisationOf: 
						(furigDistribution collect: [:each | each first < each second])).
	
	^{self stringMeanOf: someResults.
	self studentTestOf: prototypeDistribution.
	self pearsonTestOf: prototypeDistribution.
	self studentTestOf: furigDistribution.
	self pearsonTestOf: furigDistribution.
	furigEvolution roundTo: 0.01}! !

!Prototypicality methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:52'!
experiment

	"this experiment compares original data of learned probes (from one category), their prototype and a probe from an other category
	the specificity of this experiment is that two really different categories are used (the differenciationThreshold is lowered to -0.49)"

	| probes prototype category categories pekig |
	
	self differenciationThreshold: -0.49.
	
	numberOfprobes := (4 to: 8) atRandom.
	
	categories := self randomDifferentProbes: 2 with: numberOfprobes.
		category := categories first / (categories first abs).
		pekig := categories second.
	probes := self randomSignificantProbes: numberOfprobes with: numberOfprobes.
		probes := probes abs collect: [:eachProbe | eachProbe * category].
	prototype := self meanOf: probes.
	
	^{{{probes. {prototype. pekig}, probes}}}! !

!Prototypicality methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:53'!
fluencesOf: someResults 

	"collect the fluences needed from the results"

	| protypeFluence probesFluences pekigFluence |
	
	protypeFluence := someResults first first second first first first.
	pekigFluence := someResults first first second second first first.
	probesFluences := (3 to: (numberOfprobes + 2)) collect: [:each | (someResults first first second at: each) first first].
	
	^{self meanOf: probesFluences. protypeFluence. pekigFluence}! !

!Prototypicality methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:23'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ! !

!Prototypicality methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:26'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!Prototypicality methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:32'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self fluencesOf: (self run: (self experiment)))].
			self clean].
	
	^self evaluationsOf: results! !

MinervaExperiments subclass: #Reverb
	instanceVariableNames: 'numberOfExperimentations intraModalities'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!Reverb methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:54'!
classificationOf: someResults 

	"collect the echoes needed from each position in each experiment"

	^(1 to: 6) collect: [:eachPosition |
			someResults inject: #() into: [:sum :eachExperiment |
				(eachExperiment at: eachPosition), sum]]! !

!Reverb methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:55'!
echoesOf: someResults

	"collect the needed echoes from the results"

	| echoes order |
	
	echoes := someResults first first second collect: [:each | each second].
	order := MinervaExperiments indexOfRandomOrder collect: [:each | each * intraModalities - intraModalities].

	^(1 to: 6) collect: [:index |
		(1 to: intraModalities) collect: [:intra |
			(1 to: 6) collect: [:echoPosition |
				(echoes at: echoPosition) at: ((order at: index) + intra)]]]! !

!Reverb methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 17:55'!
evaluationsOf: someResults 

	"perform the needed tests"

	| results means students |
	
	results := self classificationOf: someResults.

	means := results collect: [:each | self stringMeanOf: (each)].
	
	students := results collect: [:eachPosition |
					(1 to: 5) collect: [:each |
						self studentTestBetween:  
							(eachPosition collect: [:eachProbe | eachProbe at: each])
						and:
							(eachPosition collect: [:eachProbe | eachProbe at: (each + 1)])]].
					
	^{means. students}! !

!Reverb methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 18:01'!
experiment 

	"this experiment is used for both reverb and reverse reverb.
	we are looking here for the residual echoes in timey near probes.
	This is why the presentation order is randomed, so spacy near probes are not influent,
	and the number of modalities is randomed too, so we can really look at a souvenir as a whole"

	| probes |
	
	intraModalities := (1 to: 3) atRandom.
	
	probes := (1 to: 6) collect: [:x | 
					(1 to: (6 * intraModalities)) collect: [:y | 0]].
				
	(0 to: (5 * intraModalities) by: intraModalities) doWithIndex: [:each :index | 
		(1 to: intraModalities) do: [:modality |
			(probes at: index) at: (each + modality) put: (self randomSignificantValue abs)]].
	
	probes := self randomOrderOf: probes.
	
	^{{{self repeatProbes: probes. probes}}}! !

!Reverb methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:23'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ! !

!Reverb methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:26'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!Reverb methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:32'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self echoesOf: (self run: (self experiment)))].
			self clean].
	
	^self evaluationsOf: results! !

MinervaExperiments subclass: #SelectiveRetrieval
	instanceVariableNames: 'numberOfExperimentations'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!SelectiveRetrieval methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 18:03'!
evaluationOf: someResults

	"perform the needed test from the results"

	| inter intra |
	
	inter := OrderedCollection new.
	intra := OrderedCollection new.
	
	someResults do: [:eachExperiment |
		eachExperiment do: [:eachList |
			inter addAll: eachList.
			intra addAll: ((1 to: 3) collect: [:x |
				(1 to: 3) collect: [:y | (eachList at: y) at: x]])]].
			
	^{self pearsonTestOf: inter. self pearsonTestOf: intra}! !

!SelectiveRetrieval methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:34'!
experiment 

	"This experiment create two lists of different words, each containing 0, 1 and 2 instances of each word.
	These lists are integrated, then each word in both contexts are tested.
	To achieve it, 11 modalities of each probe is dedicated to words, 3 to context.
	Even if context has almost 4 times less modalities than words, it shows that list context effect
	is more effective in retrieval than words effect."

	| probes contexts firstContextWords secondContextWords probesToTest |
	
	probes := self randomDifferentProbes: 9 with: 11.
	contexts := self randomDifferentProbes: 2 with: 3.
	
	firstContextWords := {probes fourth. probes fifth. probes sixth}, (self repeatProbes: {probes seventh. probes eighth. probes ninth}).
		firstContextWords := self randomOrderOf: (firstContextWords collect: [:each | each, (contexts first)]).
		
	secondContextWords := {probes second. probes fifth. probes eighth}, (self repeatProbes: {probes third. probes sixth. probes ninth}).
		secondContextWords := self randomOrderOf: (secondContextWords collect: [:each | each , (contexts second)]).
		
	probesToTest := (probes collect: [:each | each, (contexts first)]),
						(probes collect: [:each | each, (contexts second)]).
		
	^{{{firstContextWords, secondContextWords. probesToTest}}}! !

!SelectiveRetrieval methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:35'!
fluencesOf: someResults 

	"collect the fluences of each presentation"

	| firstList secondList |
	
	firstList := (0 to: 6 by: 3) collect: [:x |
					(1 to: 3) collect: [:y | ((someResults first first second) at: (x + y)) first first]].
	
	secondList := (1 to: 3) collect: [:x |
					(9 to: 15 by: 3) collect: [:y | ((someResults first first second) at: (x + y)) first first]].
				
	^{firstList. secondList}! !

!SelectiveRetrieval methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:23'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self  numberOfExperimentations ! !

!SelectiveRetrieval methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:26'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!SelectiveRetrieval methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:32'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self fluencesOf: (self run: (self experiment)))].
			self clean].
		
	^{self valuesOf: results. 
	self evaluationOf: results}! !

!SelectiveRetrieval methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:36'!
valuesOf: someResults 

	"perform the needed means to collect relevant values"

	| doubleListed interListed invertedList intraListed |
	
	doubleListed := self meanOf: (someResults collect: [:each | self meanOf: each]).
	
	interListed := self meanOf: (doubleListed).
	
	invertedList := someResults collect: [:eachExperiment |
						eachExperiment collect: [:eachList |
									(1 to: 3) collect: [:x |
									(1 to: 3) collect: [:y |
										(eachList at: y) at: x]]]].
	intraListed := self meanOf: (self meanOf: (invertedList collect: [:each | self meanOf: each])).
				
	^{doubleListed. interListed. intraListed}! !

MinervaExperiments subclass: #SerialPositionEffect
	instanceVariableNames: 'numberOfExperimentations'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!SerialPositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:36'!
analysisOf: someResults 

	"perform the needed tests from results"

	| interDistributions intraDistributions totalDistributions studentTests |
	
	interDistributions := (1 to: 5) collect: [:eachModality |
							someResults collect: [:eachExperiment | eachExperiment first at: eachModality]].
	intraDistributions := (1 to: 5) collect: [:eachModality |
							someResults collect: [:eachExperiment | eachExperiment second at: eachModality]].
	totalDistributions := (1 to: 5) collect: [:index |
							(interDistributions at: index), (intraDistributions at: index)].
						
	studentTests := {interDistributions. intraDistributions. totalDistributions} collect: [:eachDistribution |
						(1 to: 4) collect: [:eachRelation |
							self studentTestBetween: (eachDistribution at: eachRelation) 
								and: (eachDistribution at: (eachRelation + 1))]].
						
	^{{interDistributions collect: [:each | self stringMeanOf: each]. 
	intraDistributions collect: [:each | self stringMeanOf: each]. 
	totalDistributions collect: [:each | self stringMeanOf: each]}. 
	studentTests}! !

!SerialPositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:38'!
experiment

	"creates two lists with two different kinds of difference between each item.
	The first one is about intra-modalities differences,
	the second one is about inter-modalities differences.
	Two minervas test these lists in order to compare them"

	| intraProbes interProbes |
	
	intraProbes := self randomDifferentProbes: 5 with: 5.
	
	interProbes := (1 to: 5) collect: [:x | (1 to: 5) collect: [:y | 0]].
			(1 to: 5) do: [:index | 
				(interProbes at: index) at: index put: (self randomSignificantValue)].
				
	^{{{self repeatProbes: intraProbes. intraProbes}}. {{self repeatProbes: interProbes. interProbes}}}! !

!SerialPositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:38'!
fluencesOf: someResults 

	"collect the fluences of each probe tested"

	^someResults collect: [:eachMinerva |
		(eachMinerva first second) collect: [:eachProbe |
			eachProbe first first]]! !

!SerialPositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:23'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ! !

!SerialPositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:27'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!SerialPositionEffect methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:33'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self normalizationOf: (self fluencesOf: (self run: (self experiment))))].
			self clean].
	
	^self analysisOf: results! !

MinervaExperiments subclass: #StandardFrequencyDiscriminationTask
	instanceVariableNames: 'numberOfExperimentations'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!StandardFrequencyDiscriminationTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:43'!
experiment

	"tests the effect of repetition in remembering.
	4 minervas are used with the same list of words.
	each of them has a different number of presentation of each probe (1 to 4).
	then, for all of them, the probe to test is tested between each of its 4 presentations"
	
	^(1 to: 4) collect: [:index | | probes testProbe |
		probes := self randomDifferentProbes: 4 with: 4.
		testProbe := {probes last}.
		{{self randomOrderOf: (self repeat: index probes: probes). testProbe}. 
			{testProbe. testProbe}. {testProbe. testProbe}. {testProbe. testProbe}}]! !

!StandardFrequencyDiscriminationTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:44'!
fluencesOf: someResults 

	"collect the fluences of each presented probe in results"

	^someResults collect: [:eachMinerva |
		eachMinerva collect: [:eachRound |
			eachRound second first first first]]! !

!StandardFrequencyDiscriminationTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:23'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations! !

!StandardFrequencyDiscriminationTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:58'!
interPearsonOf: someResults 

	"perform the needed tests about inter"

	^(1 to: 4) collect: [:each |
		self pearsonTestOf:
			(someResults collect: [:eachExperiment | | values |
				values := OrderedCollection new.
				eachExperiment do: [:eachProbe | values add: (eachProbe at: each)].
				values])]! !

!StandardFrequencyDiscriminationTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:58'!
intraPearsonOf: someResults 

	"perform the needed tests about intra"

	^(1 to: 4) collect: [:each |
		self pearsonTestOf:
			(someResults collect: [:eachExperiment | eachExperiment at: each])]! !

!StandardFrequencyDiscriminationTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:27'!
numberOfExperimentations

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!StandardFrequencyDiscriminationTask methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:33'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self fluencesOf: (self run: (self experiment)))].
			self clean].
		
	^{self meanOf: results. self standartDeviationOf: results.
	self intraPearsonOf: results. self interPearsonOf: results}! !

MinervaExperiments subclass: #TestMinerva
	instanceVariableNames: 'probes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!TestMinerva methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 17:17'!
initialize 

	"initialization of the object and its variables"
	
	super initialize.
	self mimi ; clean! !

!TestMinerva methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 17:23'!
run

	"basic method for integration of repeated probes,
	 then show in Transcript tested probes"

	probes :=#(
		#(1 0 0 0 0 0 0 0)
		#(0 1 0 0 0 0 0 0)
		#(0 0 1 0 0 0 0 0)
		#(0 0 0 1 0 0 0 0)
		#(0 0 0 0 1 0 0 0)
		#(0 0 0 0 0 1 0 0)
		#(0 0 0 0 0 0 1 0)
		#(0 0 0 0 0 0 0 1)).
	
	self integrate: (self repeatProbes: probes).
	self testShowTranscript: probes! !

MinervaExperiments subclass: #TuckerEllis98
	instanceVariableNames: 'numberOfExperimentations fitCongruent fitIncongruent upsideCongruent upsideIncongruent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MetaMinerva-Experiments'!

!TuckerEllis98 methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 16:58'!
evaluationOf: someResults

	"perform all needed tests from results"

	self setPopulationsOf: someResults.
	
	^{(self meanOf: (self booleanisationOf: ((1 to: numberOfExperimentations) collect: [:index | 
			{(fitCongruent at: index) > 0. (fitIncongruent at: index) > 0. (upsideCongruent at: index) < 0. (upsideIncongruent at: index) < 0}]))) roundTo: 0.01.
	{self meanOf: fitCongruent. self meanOf: fitIncongruent. self meanOf: upsideCongruent. self meanOf: upsideIncongruent}.
	{self standartDeviationOf: fitCongruent. self standartDeviationOf: fitIncongruent. self standartDeviationOf: upsideCongruent. self standartDeviationOf: upsideIncongruent}.
	{self studentTestBetween: fitCongruent and: upsideCongruent.
	  self studentTestBetween: fitIncongruent and: upsideIncongruent.
	  self studentTestBetween: fitCongruent and: fitIncongruent.
	  self studentTestBetween: upsideCongruent and: upsideIncongruent}}! !

!TuckerEllis98 methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/8/2013 16:22'!
experiment

	"This is the famous Tucker & Ellis (1998) experiment about enaction.
	The first modality is about the hand used, the second about handle cup.
	The three lasts modalities are about the cup (with reverted values for upside down cup).
	First and second probes are repeated to emulate attention"

	| knowledge testProbes |
	
	knowledge := self randomOrderOf: #(
		#( 1  0  1 -1  1) "right side perceptive cup is right sided: answer is right hand"
		#(-1  0 -1  1 -1) "upside down perceptive cup is upside down: answer is left hand"
		#( 1  0  1 -1  1)
		#(-1  0 -1  1 -1)
		#( 1  1  0  0  0) "right handle cup is grasped with right hand"
		#(-1 -1  0  0  0)). "left handle cup is grasped with left hand"
		
	testProbes := #(
		#( 0  1  1 -1  1) "right side cup with right handed handle cup"
		#( 0 -1  1 -1  1) "right side cup with left handed handle cup"
		#( 0 -1 -1  1 -1) "upside down cup with left handed handle cup"
		#( 0  1 -1  1 -1)). "upside down cup with right handed handle cup"
		
	^{{{knowledge. testProbes}}}! !

!TuckerEllis98 methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/5/2013 16:24'!
initialize 

	"initialization of the object and its variables"

	super initialize.
	self numberOfExperimentations ! !

!TuckerEllis98 methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/8/2013 16:10'!
numberOfExperimentations 

	"numberOfExperimentations for this experiment"

	^numberOfExperimentations ifNil: [numberOfExperimentations := 5000]! !

!TuckerEllis98 methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/8/2013 16:12'!
reactionsOf: someResults 

	"collect hand modality in the results echoes (this is the enactic answer of the model)"

	^someResults first first second collect: [:each | each second first]! !

!TuckerEllis98 methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/6/2013 17:10'!
setPopulationsOf: someResults

	"allocate results in congruent lists in order to compare them"

	fitCongruent := OrderedCollection new.
	fitIncongruent := OrderedCollection new.
	upsideCongruent := OrderedCollection new.
	upsideIncongruent := OrderedCollection new.
	
	someResults do: [:eachExperiment |
		fitCongruent add: (eachExperiment first).
		fitIncongruent add: (eachExperiment second).
		upsideCongruent add: (eachExperiment third).
		upsideIncongruent add: (eachExperiment fourth)].! !

!TuckerEllis98 methodsFor: 'as yet unclassified' stamp: 'JohanBriglia 9/8/2013 16:12'!
stats

	"perform the necessary integration and tests
	this is the method used to launch the experiment"

	| results |
	
	results := OrderedCollection new.
	
	UIManager default 
		displayProgress: 'Statistics' 
		at: Display center from: 0 to: numberOfExperimentations
		during: [ :bar |
			(1 to: numberOfExperimentations) do: [ :index |
				bar value: index.
				results add: (self reactionsOf: (self run: (self experiment)))].
			self clean].
		
	^self evaluationOf: results! !
